.. _release-3000-4:

=========================
Salt 3000.4 Release Notes
=========================

Version 3000.4 is a CVE fix release for :ref:`3000 <release-3000>`.

Fixed
-----

- Prevent shell injections in netapi ssh client (cve-2020-16846)
- Prevent creating world readable private keys with the tls execution module. (cve-2020-17490)
